@@ -83,78 +83,53 @@ pub fn call_info(
 #[cfg(test)]
 #[cfg(feature = "slow_tests")]
 pub mod test {
-    use crate::conductor::ConductorBuilder;
-    use crate::core::ribosome::MockDnaStore;
-    use crate::fixt::ZomeCallHostAccessFixturator;
-    use crate::sweettest::SweetConductor;
-    use crate::sweettest::SweetDnaFile;
-    use ::fixt::prelude::*;
     use holochain_wasm_test_utils::TestWasm;
     use holochain_zome_types::prelude::*;
+    use crate::core::ribosome::wasm_test::RibosomeTestFixture;
 
     #[tokio::test(flavor = "multi_thread")]
-    async fn invoke_import_call_info_test() {
-        let host_access = fixt!(ZomeCallHostAccess, Predictable);
-        let call_info: CallInfo =
-            crate::call_test_ribosome!(host_access, TestWasm::ZomeInfo, "call_info", ()).unwrap();
-        assert_eq!(call_info.as_at.1, 2);
+    async fn call_info_test() {
+        observability::test_run().ok();
+        let RibosomeTestFixture {
+            conductor,
+            alice,
+            ..
+        } = RibosomeTestFixture::new(TestWasm::ZomeInfo).await;
+
+        let call_info: CallInfo = conductor.call(&alice, "call_info", ()).await;
+        assert_eq!(call_info.as_at.1, 3);
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn call_info_provenance_test() {
         observability::test_run().ok();
-        let (dna_file, _) = SweetDnaFile::unique_from_test_wasms(vec![TestWasm::ZomeInfo])
-            .await
-            .unwrap();
-
-        let alice_pubkey = fixt!(AgentPubKey, Predictable, 0);
-        let bob_pubkey = fixt!(AgentPubKey, Predictable, 1);
-
-        let mut dna_store = MockDnaStore::new();
-        dna_store.expect_add_dnas::<Vec<_>>().return_const(());
-        dna_store.expect_add_entry_defs::<Vec<_>>().return_const(());
-        dna_store.expect_add_dna().return_const(());
-        dna_store
-            .expect_get()
-            .return_const(Some(dna_file.clone().into()));
-        dna_store
-            .expect_get_entry_def()
-            .return_const(EntryDef::default_with_id("thing"));
-
-        let mut conductor =
-            SweetConductor::from_builder(ConductorBuilder::with_mock_dna_store(dna_store)).await;
-
-        let apps = conductor
-            .setup_app_for_agents(
-                "app-",
-                &[alice_pubkey.clone(), bob_pubkey.clone()],
-                &[dna_file.into()],
-            )
-            .await
-            .unwrap();
-
-        let ((alice,), (bobbo,)) = apps.into_tuples();
-        let alice = alice.zome(TestWasm::ZomeInfo);
-        let bobbo = bobbo.zome(TestWasm::ZomeInfo);
+        let RibosomeTestFixture {
+            conductor,
+            alice,
+            alice_pubkey,
+            bob,
+            bob_pubkey,
+            ..
+        } = RibosomeTestFixture::new(TestWasm::ZomeInfo).await;
 
         let _: () = conductor.call(&alice, "set_access", ()).await;
-        let _: () = conductor.call(&bobbo, "set_access", ()).await;
+        let _: () = conductor.call(&bob, "set_access", ()).await;
 
         let alice_call_info: CallInfo = conductor.call(&alice, "call_info", ()).await;
-        let bobbo_call_info: CallInfo = conductor.call(&bobbo, "call_info", ()).await;
-        let bobbo_call_alice_call_info: CallInfo = conductor
-            .call(&bobbo, "remote_call_info", alice_pubkey.clone())
+        let bob_call_info: CallInfo = conductor.call(&bob, "call_info", ()).await;
+        let bob_call_alice_call_info: CallInfo = conductor
+            .call(&bob, "remote_call_info", alice_pubkey.clone())
             .await;
-        let alice_call_bobbo_call_alice_call_info: CallInfo = conductor
+        let alice_call_bob_call_alice_call_info: CallInfo = conductor
             .call(&alice, "remote_remote_call_info", bob_pubkey.clone())
             .await;
 
         // direct calls to alice/bob should have their own provenance
         assert_eq!(alice_call_info.provenance, alice_pubkey);
-        assert_eq!(bobbo_call_info.provenance, bob_pubkey);
+        assert_eq!(bob_call_info.provenance, bob_pubkey);
         // Bob calling into alice should have bob provenance.
-        assert_eq!(bobbo_call_alice_call_info.provenance, bob_pubkey);
+        assert_eq!(bob_call_alice_call_info.provenance, bob_pubkey);
         // Alice calling back into herself via. bob should have bob provenance.
-        assert_eq!(alice_call_bobbo_call_alice_call_info.provenance, bob_pubkey);
+        assert_eq!(alice_call_bob_call_alice_call_info.provenance, bob_pubkey);
     }
 }
