@@ -4,7 +4,6 @@ use crate::core::ribosome::RibosomeError;
 use crate::core::ribosome::RibosomeT;
 use holochain_cascade::Cascade;
 use holochain_p2p::actor::GetOptions as NetworkGetOptions;
-use holochain_p2p::event::GetRequest;
 use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use holochain_wasmer_host::prelude::*;
@@ -22,30 +21,19 @@ pub fn must_get_header<'a>(
             ..
         } => {
             let header_hash = input.into_inner();
-            let network = call_context.host_context.network().clone();
 
             // timeouts must be handled by the network
             tokio_helper::block_forever_on(async move {
                 let workspace = call_context.host_context.workspace();
-                let mut cascade = Cascade::from_workspace_network(&workspace, network);
+                let mut cascade = match call_context.host_context {
+                    HostContext::Validate(_) => Cascade::from_workspace(workspace.stores(), None),
+                    _ => Cascade::from_workspace_network(
+                        &workspace,
+                        call_context.host_context.network().clone(),
+                    ),
+                };
                 match cascade
-                    .retrieve_header(
-                        header_hash.clone(),
-                        // Set every GetOptions manually here.
-                        // Using defaults is dangerous in a must_get as it can undermine determinism.
-                        // We want refactors to explicitly consider this.
-                        NetworkGetOptions {
-                            remote_agent_count: None,
-                            timeout_ms: None,
-                            as_race: true,
-                            race_timeout_ms: None,
-                            // Never redirect as the returned entry must always match the hash.
-                            follow_redirects: false,
-                            all_live_headers_with_metadata: false,
-                            // Redundant with retrieve_entry internals.
-                            request_type: GetRequest::Pending,
-                        },
-                    )
+                    .retrieve_header(header_hash.clone(), NetworkGetOptions::must_get_options())
                     .await
                     .map_err(|cascade_error| WasmError::Host(cascade_error.to_string()))?
                 {
