@@ -16,9 +16,11 @@ use crate::core::ribosome::RibosomeT;
 use crate::core::ribosome::ZomesToInvoke;
 use error::AppValidationResult;
 pub use error::*;
+use futures::stream::StreamExt;
 use holo_hash::DhtOpHash;
 use holochain_cascade::Cascade;
 use holochain_keystore::MetaLairClient;
+use holochain_p2p::actor::GetOptions as NetworkGetOptions;
 use holochain_p2p::HolochainP2pDna;
 use holochain_p2p::HolochainP2pDnaT;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
@@ -29,6 +31,7 @@ use holochain_types::prelude::*;
 use holochain_zome_types::op::EntryCreationHeader;
 use holochain_zome_types::op::Op;
 use rusqlite::Transaction;
+use std::collections::HashSet;
 use tracing::*;
 pub use types::Outcome;
 
@@ -133,7 +136,6 @@ async fn app_validation_workflow_inner(
     // Create a stream of concurrent validation futures.
     // This will run NUM_CONCURRENT_OPS validation futures concurrently and
     // return up to NUM_CONCURRENT_OPS * 100 results.
-    use futures::stream::StreamExt;
     let mut iter = futures::stream::iter(iter)
         .buffer_unordered(NUM_CONCURRENT_OPS)
         .ready_chunks(NUM_CONCURRENT_OPS * 100);
@@ -264,13 +266,6 @@ async fn app_validation_workflow_inner(
     })
 }
 
-pub fn to_single_zome(zomes_to_invoke: ZomesToInvoke) -> AppValidationResult<Zome> {
-    match zomes_to_invoke {
-        ZomesToInvoke::All => Err(AppValidationError::LinkMultipleZomes),
-        ZomesToInvoke::One(z) => Ok(z),
-    }
-}
-
 pub async fn element_to_op(
     element: Element,
     op_type: DhtOpType,
@@ -280,7 +275,7 @@ pub async fn element_to_op(
     let mut activity_entry = None;
     let (shh, entry) = element.into_inner();
     let mut entry = entry.into_option();
-    let (header, _) = shh.into_inner();
+    let header = shh.into();
     // Register agent activity doesn't store the entry so we need to
     // save it so we can reconstruct the element later.
     if matches!(op_type, RegisterAgentActivity) {
@@ -359,9 +354,10 @@ async fn dhtop_to_op(op: DhtOp, cascade: &mut Cascade) -> AppValidationOutcome<O
             let original_header = cascade
                 .retrieve_header(update.original_header_address.clone(), Default::default())
                 .await?
-                .and_then(|e| {
-                    let sh = e.into_inner().0;
-                    NewEntryHeader::try_from(sh.0).ok().map(|h| h.into())
+                .and_then(|sh| {
+                    NewEntryHeader::try_from(sh.hashed.content)
+                        .ok()
+                        .map(|h| h.into())
                 })
                 .ok_or_else(|| Outcome::awaiting(&update.original_header_address))?;
             Op::RegisterUpdate {
@@ -382,9 +378,10 @@ async fn dhtop_to_op(op: DhtOp, cascade: &mut Cascade) -> AppValidationOutcome<O
             let original_header = cascade
                 .retrieve_header(delete.deletes_address.clone(), Default::default())
                 .await?
-                .and_then(|e| {
-                    let sh = e.into_inner().0;
-                    NewEntryHeader::try_from(sh.0).ok().map(|h| h.into())
+                .and_then(|sh| {
+                    NewEntryHeader::try_from(sh.hashed.content)
+                        .ok()
+                        .map(|h| h.into())
                 })
                 .ok_or_else(|| Outcome::awaiting(&delete.deletes_address))?;
             Op::RegisterDelete {
@@ -400,10 +397,7 @@ async fn dhtop_to_op(op: DhtOp, cascade: &mut Cascade) -> AppValidationOutcome<O
             let create_link = cascade
                 .retrieve_header(delete_link.link_add_address.clone(), Default::default())
                 .await?
-                .and_then(|e| {
-                    let sh = e.into_inner().0;
-                    CreateLink::try_from(sh.0).ok()
-                })
+                .and_then(|sh| CreateLink::try_from(sh.hashed.content).ok())
                 .ok_or_else(|| Outcome::awaiting(&delete_link.link_add_address))?;
             Op::RegisterDeleteLink {
                 delete_link: SignedHashed::new(delete_link, signature),
@@ -422,7 +416,7 @@ async fn validate_op_outer(
     network: &HolochainP2pDna,
 ) -> AppValidationOutcome<Outcome> {
     // Get the workspace for the validation calls
-    let workspace = workspace.validation_workspace().await?;
+    let host_fn_workspace = workspace.validation_workspace().await?;
 
     // Get the dna file
     let dna_file = conductor_handle
@@ -431,15 +425,18 @@ async fn validate_op_outer(
 
     // Create the ribosome
     let ribosome = RealRibosome::new(dna_file);
-    validate_op(op, workspace, network, &ribosome).await
+    validate_op(op, host_fn_workspace, network, &ribosome).await
 }
 
-pub async fn validate_op(
+pub async fn validate_op<R>(
     op: &Op,
     workspace: HostFnWorkspaceRead,
     network: &HolochainP2pDna,
-    ribosome: &impl RibosomeT,
-) -> AppValidationOutcome<Outcome> {
+    ribosome: &R,
+) -> AppValidationOutcome<Outcome>
+where
+    R: RibosomeT,
+{
     let zomes_to_invoke = match op {
         Op::RegisterAgentActivity { .. } | Op::StoreElement { .. } => ZomesToInvoke::All,
         Op::StoreEntry {
@@ -478,7 +475,14 @@ pub async fn validate_op(
 
     let invocation = ValidateInvocation::new(zomes_to_invoke, op)
         .map_err(|e| AppValidationError::RibosomeError(e.into()))?;
-    let outcome = run_validation_callback_inner(invocation, ribosome, workspace, network.clone())?;
+    let outcome = run_validation_callback_inner(
+        invocation,
+        ribosome,
+        workspace,
+        network.clone(),
+        (HashSet::<AnyDhtHash>::new(), 0),
+    )
+    .await?;
 
     Ok(outcome)
 }
@@ -521,24 +525,69 @@ fn zome_id_to_zome(zome_id: ZomeId, dna_def: &DnaDef) -> AppValidationResult<Zom
         .into())
 }
 
-fn run_validation_callback_inner(
+#[async_recursion::async_recursion]
+async fn run_validation_callback_inner<R>(
     invocation: ValidateInvocation,
-    ribosome: &impl RibosomeT,
-    workspace_lock: HostFnWorkspaceRead,
+    ribosome: &R,
+    workspace_read: HostFnWorkspaceRead,
     network: HolochainP2pDna,
-) -> AppValidationResult<Outcome> {
-    let validate: ValidateResult =
-        ribosome.run_validate(ValidateHostAccess::new(workspace_lock, network), invocation)?;
-    match validate {
+    (mut fetched_deps, recursion_depth): (HashSet<AnyDhtHash>, usize),
+) -> AppValidationResult<Outcome>
+where
+    R: RibosomeT,
+{
+    let validate_result = ribosome.run_validate(
+        ValidateHostAccess::new(workspace_read.clone(), network.clone()),
+        invocation.clone(),
+    )?;
+    match validate_result {
         ValidateResult::Valid => Ok(Outcome::Accepted),
         ValidateResult::Invalid(reason) => Ok(Outcome::Rejected(reason)),
-        ValidateResult::UnresolvedDependencies(hashes) => Ok(Outcome::AwaitingDeps(hashes)),
+        ValidateResult::UnresolvedDependencies(hashes) => {
+            // This is the base case where we've been recursing and start seeing
+            // all the same hashes unresolved that we already tried to fetch.
+            // At this point we should just give up on the inline recursing and
+            // let some future background task attempt to fetch these hashes
+            // again. Hopefully by then the hashes are fetchable.
+            // 20 is a completely arbitrary max recursion depth.
+            if recursion_depth < 20 || hashes.iter().all(|hash| fetched_deps.contains(hash)) {
+                Ok(Outcome::AwaitingDeps(hashes))
+            } else {
+                let in_flight = hashes.into_iter().map(|hash| async {
+                    let cascade_workspace = workspace_read.clone();
+                    let mut cascade =
+                        Cascade::from_workspace_network(&cascade_workspace, network.clone());
+                    cascade
+                        .fetch_element(hash.clone(), NetworkGetOptions::must_get_options())
+                        .await?;
+                    Ok(hash)
+                });
+                let results: Vec<_> = futures::stream::iter(in_flight)
+                    // 10 is completely arbitrary.
+                    .buffered(10)
+                    .collect()
+                    .await;
+                let results: AppValidationResult<Vec<_>> = results.into_iter().collect();
+                for hash in results? {
+                    fetched_deps.insert(hash);
+                }
+                run_validation_callback_inner(
+                    invocation,
+                    ribosome,
+                    workspace_read,
+                    network,
+                    (fetched_deps, recursion_depth + 1),
+                )
+                .await
+            }
+        }
     }
 }
 
 pub struct AppValidationWorkspace {
     authored_db: DbRead<DbKindAuthored>,
     dht_db: DbWrite<DbKindDht>,
+    dht_db_cache: DhtDbQueryCache,
     cache: DbWrite<DbKindCache>,
     keystore: MetaLairClient,
     dna_def: Arc<DnaDef>,
@@ -548,6 +597,7 @@ impl AppValidationWorkspace {
     pub fn new(
         authored_db: DbRead<DbKindAuthored>,
         dht_db: DbWrite<DbKindDht>,
+        dht_db_cache: DhtDbQueryCache,
         cache: DbWrite<DbKindCache>,
         keystore: MetaLairClient,
         dna_def: Arc<DnaDef>,
@@ -555,6 +605,7 @@ impl AppValidationWorkspace {
         Self {
             authored_db,
             dht_db,
+            dht_db_cache,
             cache,
             keystore,
             dna_def,
@@ -565,6 +616,7 @@ impl AppValidationWorkspace {
         Ok(HostFnWorkspace::new(
             self.authored_db.clone(),
             self.dht_db.clone().into(),
+            self.dht_db_cache.clone(),
             self.cache.clone(),
             self.keystore.clone(),
             None,
