@@ -74,7 +74,7 @@ fn expected_invalid_entry(
     let sql = format!(
         "
         {}
-        type = :store_entry AND header_hash = :invalid_header_hash 
+        type = :store_entry AND header_hash = :invalid_header_hash
             AND basis_hash = :invalid_entry_hash AND validation_status = :rejected
     ",
         SELECT
@@ -100,7 +100,7 @@ fn expected_invalid_link(txn: &Transaction, invalid_link_hash: &HeaderHash) -> b
     let sql = format!(
         "
         {}
-        type = :create_link AND header_hash = :invalid_link_hash 
+        type = :create_link AND header_hash = :invalid_link_hash
             AND validation_status = :rejected
     ",
         SELECT
@@ -125,7 +125,7 @@ fn expected_invalid_remove_link(txn: &Transaction, invalid_remove_hash: &HeaderH
     let sql = format!(
         "
         {}
-        (type = :delete_link AND header_hash = :invalid_remove_hash 
+        (type = :delete_link AND header_hash = :invalid_remove_hash
             AND validation_status = :rejected)
     ",
         SELECT
@@ -160,7 +160,7 @@ fn show_limbo(txn: &Transaction) -> Vec<DhtOpLight> {
     txn.prepare(
         "
         SELECT DhtOp.type, Header.hash, Header.blob
-        FROM DhtOp 
+        FROM DhtOp
         JOIN Header ON DhtOp.header_hash = Header.hash
         WHERE
         when_integrated IS NULL
@@ -180,7 +180,7 @@ fn show_limbo(txn: &Transaction) -> Vec<DhtOpLight> {
 
 fn num_valid(txn: &Transaction) -> usize {
     txn
-    .query_row("SELECT COUNT(hash) FROM DhtOP WHERE when_integrated IS NOT NULL AND validation_status = :status", 
+    .query_row("SELECT COUNT(hash) FROM DhtOP WHERE when_integrated IS NOT NULL AND validation_status = :status",
             named_params!{
                 ":status": ValidationStatus::Valid,
             },
@@ -208,16 +208,12 @@ async fn run_test(
     // Plus another 16 for genesis + init
     // Plus 2 for Cap Grant
     let expected_count = 3 + 16 + 2;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -233,12 +229,10 @@ async fn run_test(
     // StoreEntry should be invalid.
     // RegisterAgentActivity will be valid.
     let expected_count = 3 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -258,12 +252,10 @@ async fn run_test(
 
     // Integration should have 6 ops in it
     let expected_count = 6 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -287,12 +279,10 @@ async fn run_test(
 
     // Integration should have 9 ops in it
     let expected_count = 9 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -318,12 +308,10 @@ async fn run_test(
 
     // Integration should have 9 ops in it
     let expected_count = 9 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -353,12 +341,10 @@ async fn run_test(
 
     // Integration should have 12 ops in it
     let expected_count = 12 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
@@ -400,12 +386,10 @@ async fn run_test_entry_def_id(
     // Integration should have 3 ops in it
     // StoreEntry and StoreElement should be invalid.
     let expected_count = 3 + expected_count;
-    let alice_env = conductors[0]
-        .get_dht_env(&alice_cell_id.dna_hash())
-        .unwrap();
-    wait_for_integration(&alice_env, expected_count, num_attempts, delay_per_attempt).await;
+    let alice_db = conductors[0].get_dht_db(&alice_cell_id.dna_hash()).unwrap();
+    wait_for_integration(&alice_db, expected_count, num_attempts, delay_per_attempt).await;
 
-    fresh_reader_test(alice_env, |txn| {
+    fresh_reader_test(alice_db, |txn| {
         // Validation should be empty
         let limbo = show_limbo(&txn);
         assert!(limbo_is_empty(&txn), "{:?}", limbo);
