@@ -32,6 +32,7 @@ use holochain_p2p::HolochainP2pDnaFixturator;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
 use holochain_state::host_fn_workspace::HostFnWorkspaceRead;
 use holochain_state::test_utils::test_keystore;
+use holochain_types::db_cache::DhtDbQueryCache;
 use holochain_types::prelude::*;
 use holochain_wasm_test_utils::TestWasm;
 use rand::seq::IteratorRandom;
@@ -243,6 +244,7 @@ fixturator!(
             HostFnWorkspace::new(
                 authored_db.to_db(),
                 dht_db.to_db(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
@@ -260,6 +262,7 @@ fixturator!(
             HostFnWorkspace::new(
                 authored_db.to_db(),
                 dht_db.to_db(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
@@ -278,6 +281,7 @@ fixturator!(
             HostFnWorkspace::new(
                 authored_db.to_db(),
                 dht_db.to_db(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(agent),
@@ -299,6 +303,7 @@ fixturator!(
             HostFnWorkspaceRead::new(
                 authored_db.to_db().into(),
                 dht_db.to_db().into(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
@@ -316,6 +321,7 @@ fixturator!(
             HostFnWorkspaceRead::new(
                 authored_db.to_db().into(),
                 dht_db.to_db().into(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
@@ -334,6 +340,7 @@ fixturator!(
             HostFnWorkspaceRead::new(
                 authored_db.to_db().into(),
                 dht_db.to_db().into(),
+                DhtDbQueryCache::new(dht_db.to_db().into()),
                 cache.to_db(),
                 keystore,
                 Some(agent),
