@@ -10,14 +10,14 @@ use futures::stream::StreamExt;
 use holo_hash::{DhtOpHash, DnaHash};
 use holochain_p2p::{
     dht_arc::{DhtArc, DhtLocation},
-    AgentPubKeyExt, DhtOpHashExt, DnaHashExt,
+    AgentPubKeyExt, DhtOpHashExt,
 };
 use holochain_sqlite::{
-    db::{AsP2pStateTxExt, DbKindAuthored, DbKindDht, DbKindP2pAgentStore},
+    db::{AsP2pStateTxExt, DbKindAuthored, DbKindDht, DbKindP2pAgents},
     prelude::DatabaseResult,
 };
 use holochain_state::prelude::StateQueryResult;
-use holochain_types::{dht_op::DhtOpType, env::DbRead};
+use holochain_types::{db::DbRead, dht_op::DhtOpType};
 use kitsune_p2p::{KitsuneAgent, KitsuneOpHash};
 use kitsune_p2p_types::consistency::*;
 use rusqlite::named_params;
@@ -26,8 +26,8 @@ use crate::conductor::ConductorHandle;
 
 struct Stores {
     agent: Arc<KitsuneAgent>,
-    authored_env: DbRead<DbKindAuthored>,
-    p2p_env: DbRead<DbKindP2pAgentStore>,
+    authored_db: DbRead<DbKindAuthored>,
+    p2p_agents_db: DbRead<DbKindP2pAgents>,
 }
 
 #[derive(Clone)]
@@ -38,7 +38,7 @@ const CONCURRENCY: usize = 100;
 /// A helper for checking consistency of all published ops for all cells in all conductors
 /// has reached consistency in a sharded context.
 pub async fn local_machine_session(conductors: &[ConductorHandle], timeout: Duration) {
-    // For each space get all the cells, their env and the p2p envs.
+    // For each space get all the cells, their db and the p2p envs.
     let mut spaces = HashMap::new();
     for (i, c) in conductors.iter().enumerate() {
         for cell_id in c.list_cell_ids(None) {
@@ -46,13 +46,13 @@ pub async fn local_machine_session(conductors: &[ConductorHandle], timeout: Dura
                 .entry(cell_id.dna_hash().clone())
                 .or_insert_with(|| vec![None; conductors.len()]);
             if space[i].is_none() {
-                let p2p_env: DbRead<DbKindP2pAgentStore> =
-                    c.get_p2p_env(cell_id.dna_hash().to_kitsune()).into();
-                space[i] = Some((p2p_env, Vec::new()));
+                let p2p_agents_db: DbRead<DbKindP2pAgents> =
+                    c.get_p2p_db(cell_id.dna_hash()).into();
+                space[i] = Some((p2p_agents_db, Vec::new()));
             }
             space[i].as_mut().unwrap().1.push((
-                c.get_authored_env(cell_id.dna_hash()).unwrap().into(),
-                c.get_dht_env(cell_id.dna_hash()).unwrap().into(),
+                c.get_authored_db(cell_id.dna_hash()).unwrap().into(),
+                c.get_dht_db(cell_id.dna_hash()).unwrap().into(),
                 cell_id.agent_pubkey().to_kitsune(),
             ));
         }
@@ -64,7 +64,7 @@ pub async fn local_machine_session(conductors: &[ConductorHandle], timeout: Dura
         let mut wait_for_agents = HashSet::new();
 
         // Maps to environments.
-        let mut agent_env_map = HashMap::new();
+        let mut agent_dht_map = HashMap::new();
         let mut agent_p2p_map = HashMap::new();
 
         // All the agents that should be held.
@@ -74,11 +74,16 @@ pub async fn local_machine_session(conductors: &[ConductorHandle], timeout: Dura
         let (tx, rx) = tokio::sync::mpsc::channel(1000);
 
         // Gather the expected agents and op hashes from each conductor.
-        for (p2p_env, agents) in conductors.into_iter().flatten() {
+        for (p2p_agents_db, agents) in conductors.into_iter().flatten() {
             wait_for_agents.extend(agents.iter().map(|(_, _, agent)| agent.clone()));
-            agent_env_map.extend(agents.iter().cloned().map(|(_, dht, agent)| (agent, dht)));
-            agent_p2p_map.extend(agents.iter().cloned().map(|(_, _, a)| (a, p2p_env.clone())));
-            let (a, h) = gather_conductor_data(p2p_env, agents).await;
+            agent_dht_map.extend(agents.iter().cloned().map(|(_, dht, agent)| (agent, dht)));
+            agent_p2p_map.extend(
+                agents
+                    .iter()
+                    .cloned()
+                    .map(|(_, _, a)| (a, p2p_agents_db.clone())),
+            );
+            let (a, h) = gather_conductor_data(p2p_agents_db, agents).await;
             all_agents.extend(a);
             all_hashes.extend(h);
         }
@@ -91,7 +96,7 @@ pub async fn local_machine_session(conductors: &[ConductorHandle], timeout: Dura
             timeout,
             all_agents,
             all_hashes,
-            agent_env_map,
+            agent_dht_map,
             agent_p2p_map,
         ));
 
@@ -115,12 +120,12 @@ pub async fn local_machine_session_with_hashes(
                 continue;
             }
             if conductors[i].is_none() {
-                let p2p_env: DbRead<DbKindP2pAgentStore> =
-                    c.get_p2p_env(cell_id.dna_hash().to_kitsune()).into();
-                conductors[i] = Some((p2p_env, Vec::new()));
+                let p2p_agents_db: DbRead<DbKindP2pAgents> =
+                    c.get_p2p_db(cell_id.dna_hash()).into();
+                conductors[i] = Some((p2p_agents_db, Vec::new()));
             }
             conductors[i].as_mut().unwrap().1.push((
-                c.get_dht_env(cell_id.dna_hash()).unwrap().into(),
+                c.get_dht_db(cell_id.dna_hash()).unwrap().into(),
                 cell_id.agent_pubkey().to_kitsune(),
             ));
         }
@@ -135,7 +140,7 @@ pub async fn local_machine_session_with_hashes(
     let mut wait_for_agents = HashSet::new();
 
     // Maps to environments.
-    let mut agent_env_map = HashMap::new();
+    let mut agent_dht_map = HashMap::new();
     let mut agent_p2p_map = HashMap::new();
 
     // All the agents that should be held.
@@ -143,12 +148,20 @@ pub async fn local_machine_session_with_hashes(
     let (tx, rx) = tokio::sync::mpsc::channel(1000);
 
     // Gather the expected agents from each conductor.
-    for (p2p_env, agents) in conductors.into_iter().flatten() {
+    for (p2p_agents_db, agents) in conductors.into_iter().flatten() {
         wait_for_agents.extend(agents.iter().map(|(_, agent)| agent.clone()));
-        agent_env_map.extend(agents.iter().cloned().map(|(e, a)| (a, e)));
-        agent_p2p_map.extend(agents.iter().cloned().map(|(_, a)| (a, p2p_env.clone())));
+        agent_dht_map.extend(agents.iter().cloned().map(|(e, a)| (a, e)));
+        agent_p2p_map.extend(
+            agents
+                .iter()
+                .cloned()
+                .map(|(_, a)| (a, p2p_agents_db.clone())),
+        );
         for (_, agent) in &agents {
-            if let Some(storage_arc) = request_arc(&p2p_env, (**agent).clone()).await.unwrap() {
+            if let Some(storage_arc) = request_arc(&p2p_agents_db, (**agent).clone())
+                .await
+                .unwrap()
+            {
                 all_agents.push((agent.clone(), storage_arc));
             }
         }
@@ -162,7 +175,7 @@ pub async fn local_machine_session_with_hashes(
         timeout,
         all_agents,
         all_hashes,
-        agent_env_map,
+        agent_dht_map,
         agent_p2p_map,
     ));
 
@@ -335,7 +348,7 @@ Average hashes held: {}%.
 
 /// Gather all the published op hashes and agents from a conductor.
 async fn gather_conductor_data(
-    p2p_env: DbRead<DbKindP2pAgentStore>,
+    p2p_agents_db: DbRead<DbKindP2pAgents>,
     agents: Vec<(DbRead<DbKindAuthored>, DbRead<DbKindDht>, Arc<KitsuneAgent>)>,
 ) -> (
     Vec<(Arc<KitsuneAgent>, DhtArc)>,
@@ -345,10 +358,10 @@ async fn gather_conductor_data(
     let stores = agents
         .iter()
         .cloned()
-        .map(|(authored_env, _, agent)| Stores {
+        .map(|(authored_db, _, agent)| Stores {
             agent,
-            authored_env,
-            p2p_env: p2p_env.clone(),
+            authored_db,
+            p2p_agents_db: p2p_agents_db.clone(),
         });
     let all_published_data = gather_published_data(stores, CONCURRENCY)
         .await
@@ -375,10 +388,10 @@ async fn expect_all(
     timeout: Duration,
     all_agents: Vec<(Arc<KitsuneAgent>, DhtArc)>,
     all_hashes: Vec<(DhtLocation, KitsuneOpHash)>,
-    agent_env_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindDht>>,
-    agent_p2p_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindP2pAgentStore>>,
+    agent_dht_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindDht>>,
+    agent_p2p_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindP2pAgents>>,
 ) {
-    let iter = generate_session(&all_agents, &all_hashes, timeout, agent_env_map);
+    let iter = generate_session(&all_agents, &all_hashes, timeout, agent_dht_map);
     check_all(iter, tx, agent_p2p_map).await;
 }
 
@@ -388,7 +401,7 @@ fn generate_session<'iter>(
     all_agents: &'iter Vec<(Arc<KitsuneAgent>, DhtArc)>,
     all_hashes: &'iter Vec<(DhtLocation, KitsuneOpHash)>,
     timeout: Duration,
-    agent_env_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindDht>>,
+    agent_dht_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindDht>>,
 ) -> impl Iterator<Item = (Arc<KitsuneAgent>, ConsistencySession, DbRead<DbKindDht>)> + 'iter {
     all_agents
         .iter()
@@ -425,10 +438,10 @@ fn generate_session<'iter>(
             )
         })
         .filter_map(move |(agent, expected_session)| {
-            agent_env_map
+            agent_dht_map
                 .get(&agent)
                 .cloned()
-                .map(|env| (agent, expected_session, env))
+                .map(|db| (agent, expected_session, db))
         })
 }
 
@@ -438,17 +451,17 @@ fn generate_session<'iter>(
 async fn check_all(
     iter: impl Iterator<Item = (Arc<KitsuneAgent>, ConsistencySession, DbRead<DbKindDht>)>,
     tx: tokio::sync::mpsc::Sender<SessionMessage>,
-    agent_p2p_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindP2pAgentStore>>,
+    agent_p2p_map: HashMap<Arc<KitsuneAgent>, DbRead<DbKindP2pAgents>>,
 ) {
     futures::stream::iter(iter)
-        .for_each_concurrent(CONCURRENCY, |(agent, expected_session, dht_env)| {
+        .for_each_concurrent(CONCURRENCY, |(agent, expected_session, dht_db)| {
             let tx = tx.clone();
-            let p2p_env = agent_p2p_map
+            let p2p_agents_db = agent_p2p_map
                 .get(&agent)
                 .cloned()
                 .expect("Must contain all p2p envs, this is a bug.");
             let reporter = Reporter(tx, agent);
-            check_expected_data(reporter, expected_session, dht_env, p2p_env)
+            check_expected_data(reporter, expected_session, dht_db, p2p_agents_db)
         })
         .await;
 }
@@ -457,10 +470,12 @@ async fn check_all(
 async fn check_expected_data(
     reporter: Reporter,
     session: ConsistencySession,
-    dht_env: DbRead<DbKindDht>,
-    p2p_env: DbRead<DbKindP2pAgentStore>,
+    dht_db: DbRead<DbKindDht>,
+    p2p_agents_db: DbRead<DbKindP2pAgents>,
 ) {
-    if let Err(e) = check_expected_data_inner(reporter.clone(), session, dht_env, p2p_env).await {
+    if let Err(e) =
+        check_expected_data_inner(reporter.clone(), session, dht_db, p2p_agents_db).await
+    {
         reporter
             .send_report(SessionReport::Error {
                 error: e.to_string(),
@@ -475,8 +490,8 @@ async fn check_expected_data(
 async fn check_expected_data_inner(
     reporter: Reporter,
     session: ConsistencySession,
-    dht_env: DbRead<DbKindDht>,
-    p2p_env: DbRead<DbKindP2pAgentStore>,
+    dht_db: DbRead<DbKindDht>,
+    p2p_agents_db: DbRead<DbKindP2pAgents>,
 ) -> DatabaseResult<()> {
     // Unpack the session.
     let ConsistencySession {
@@ -516,10 +531,12 @@ async fn check_expected_data_inner(
         }
 
         // Check the agents.
-        missing_agents = check_agents(&p2p_env, &expected_agents).await?.collect();
+        missing_agents = check_agents(&p2p_agents_db, &expected_agents)
+            .await?
+            .collect();
 
         // Check the hashes.
-        check_hashes(&dht_env, &mut expected_hashes, &mut missing_hashes).await?;
+        check_hashes(&dht_db, &mut expected_hashes, &mut missing_hashes).await?;
 
         // If both are now empty we report success.
         if missing_agents.is_empty() && missing_hashes.is_empty() {
@@ -561,11 +578,11 @@ async fn check_expected_data_inner(
 // Seems these lifetimes are actually needed.
 #[allow(clippy::needless_lifetimes)]
 async fn check_agents<'iter>(
-    p2p_env: &DbRead<DbKindP2pAgentStore>,
+    p2p_agents_db: &DbRead<DbKindP2pAgents>,
     expected_agents: &'iter [Arc<KitsuneAgent>],
 ) -> DatabaseResult<impl Iterator<Item = &'iter Arc<KitsuneAgent>> + 'iter> {
     // Poll the peer database for the currently held agents.
-    let agents_held: HashSet<_> = p2p_env
+    let agents_held: HashSet<_> = p2p_agents_db
         .async_reader(|txn| {
             DatabaseResult::Ok(
                 txn.p2p_list_agents()?
@@ -584,7 +601,7 @@ async fn check_agents<'iter>(
 
 /// Check the op hashes we are meant to be holding.
 async fn check_hashes(
-    dht_env: &DbRead<DbKindDht>,
+    dht_db: &DbRead<DbKindDht>,
     expected_hashes: &mut Vec<KitsuneOpHash>,
     missing_hashes: &mut Vec<KitsuneOpHash>,
 ) -> DatabaseResult<()> {
@@ -597,7 +614,7 @@ async fn check_hashes(
     let mut missing = std::mem::replace(missing_hashes, Vec::with_capacity(0));
 
     // Poll the vault database for each expected hashes existence.
-    let mut r = dht_env
+    let mut r = dht_db
                 .async_reader(move |txn| {
                     for hash in &expected {
                         // TODO: This might be too slow, could instead save the holochain hash versions.
@@ -633,8 +650,8 @@ async fn gather_published_data(
 ) -> StateQueryResult<Vec<PublishedData>> {
     use futures::stream::TryStreamExt;
     let iter = iter.map(|stores| async move {
-        let published_hashes = request_published_ops(&stores.authored_env).await?;
-        let storage_arc = request_arc(&stores.p2p_env, (*stores.agent).clone()).await?;
+        let published_hashes = request_published_ops(&stores.authored_db).await?;
+        let storage_arc = request_arc(&stores.p2p_agents_db, (*stores.agent).clone()).await?;
         Ok(storage_arc.map(|storage_arc| {
             // The line below was added when migrating to rust edition 2021, per
             // https://doc.rust-lang.org/edition-guide/rust-2021/disjoint-capture-in-closures.html#migration
@@ -655,9 +672,9 @@ async fn gather_published_data(
 
 /// Request the published hashes for the given agent.
 async fn request_published_ops(
-    env: &DbRead<DbKindAuthored>,
+    db: &DbRead<DbKindAuthored>,
 ) -> StateQueryResult<Vec<(DhtLocation, KitsuneOpHash)>> {
-    Ok(env
+    Ok(db
         .async_reader(|txn| {
             // Collect all ops except StoreEntry's that are private.
             let r = txn
@@ -691,9 +708,9 @@ async fn request_published_ops(
 
 /// Request the storage arc for the given agent.
 async fn request_arc(
-    env: &DbRead<DbKindP2pAgentStore>,
+    db: &DbRead<DbKindP2pAgents>,
     agent: KitsuneAgent,
 ) -> StateQueryResult<Option<DhtArc>> {
-    env.async_reader(move |txn| Ok(txn.p2p_get_agent(&agent)?.map(|info| info.storage_arc)))
+    db.async_reader(move |txn| Ok(txn.p2p_get_agent(&agent)?.map(|info| info.storage_arc)))
         .await
 }
